@@ -17,12 +17,12 @@ class Config(object):
     filepath = join(".", filename)
     # default configuration
     default = {
-        'root_path': '/',
+        'root_path': '',
         'blog': {
             'name': 'Blog\'s name',
             'description': 'Blog\'s description',
             'url': 'http://your-site.com',
-            'theme': 'classic'
+            'theme': 'less'
         },
         'author': {
             'name': 'me',
